@@ -45,7 +45,7 @@ enum
 
 #define ELLIPSISED_MENU_ITEM_MIN_CHARS  32
 
-static guint signals[LAST_SIGNAL];
+static guint signals[LAST_SIGNAL] = { 0 };
 
 struct CajaBookmarkDetails
 {
