@@ -340,8 +340,9 @@ file_list_ready_cb (GList *files,
     gtk_widget_hide (details->diff_button);
     if (!source_is_dir && !dest_is_dir)
     {
-        if (g_find_program_in_path ("meld")) {
-            
+        gchar *meld_found = g_find_program_in_path ("meld");
+        if (meld_found) {
+            g_free (meld_found);
             gboolean src_is_binary;
             gboolean dest_is_binary;
             
@@ -589,7 +590,7 @@ caja_file_conflict_dialog_init (CajaFileConflictDialog *fcd)
     details->second_hbox = hbox;
 
     /* Setup the expander for the rename action */
-    details->expander = gtk_expander_new_with_mnemonic (_("_Select a new name for the destination"));
+    details->expander = gtk_expander_new_with_mnemonic (_("Select a new name for the _destination"));
     gtk_box_pack_start (GTK_BOX (vbox2), details->expander, FALSE, FALSE, 0);
     g_signal_connect (details->expander, "activate",
                       G_CALLBACK (expander_activated_cb), dialog);
